import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { BulkCreateDraftPostsOptions, BulkCreateDraftPostsResponse, BulkCreateDraftPostsResponseNonNullableFields, BulkDeleteDraftPostsOptions, BulkDeleteDraftPostsResponse, BulkDeleteDraftPostsResponseNonNullableFields, BulkUpdateDraftPostsOptions, BulkUpdateDraftPostsResponse, BulkUpdateDraftPostsResponseNonNullableFields, CreateDraftPostOptions, CreateDraftPostResponse, CreateDraftPostResponseNonNullableFields, DeleteDraftPostOptions, DraftCreatedEnvelope, DraftDeletedEnvelope, DraftPost, DraftPostsQueryBuilder, DraftUpdatedEnvelope, GetDeletedDraftPostResponse, GetDeletedDraftPostResponseNonNullableFields, GetDraftPostOptions, GetDraftPostResponse, GetDraftPostResponseNonNullableFields, ListDeletedDraftPostsOptions, ListDeletedDraftPostsResponse, ListDeletedDraftPostsResponseNonNullableFields, ListDraftPostsOptions, ListDraftPostsResponse, ListDraftPostsResponseNonNullableFields, PublishDraftPostResponse, PublishDraftPostResponseNonNullableFields, QueryDraftPostsOptions, RestoreFromTrashBinResponse, RestoreFromTrashBinResponseNonNullableFields, UpdateDraftPost, UpdateDraftPostOptions, UpdateDraftPostResponse, UpdateDraftPostResponseNonNullableFields } from './blog-v3-draft-draft-posts.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createDraftPost(httpClient: HttpClient): CreateDraftPostSignature;
interface CreateDraftPostSignature {
    /**
     * Creates a draft post.
     *
     * The draft post's `memberId` is required for third-party apps.
     * @param - Draft post to create.
     * @param - Options for creating a draft post.
     */
    (draftPost: DraftPost, options?: CreateDraftPostOptions | undefined): Promise<CreateDraftPostResponse & CreateDraftPostResponseNonNullableFields>;
}
export declare function bulkCreateDraftPosts(httpClient: HttpClient): BulkCreateDraftPostsSignature;
interface BulkCreateDraftPostsSignature {
    /**
     * Creates multiple draft posts.
     * @param - Draft posts to create.
     * @param - Options for creating multiple draft posts.
     */
    (draftPosts: DraftPost[], options?: BulkCreateDraftPostsOptions | undefined): Promise<BulkCreateDraftPostsResponse & BulkCreateDraftPostsResponseNonNullableFields>;
}
export declare function bulkUpdateDraftPosts(httpClient: HttpClient): BulkUpdateDraftPostsSignature;
interface BulkUpdateDraftPostsSignature {
    /**
     * Updates multiple draft posts.
     * @param - Options for updating multiple draft posts.
     */
    (options?: BulkUpdateDraftPostsOptions | undefined): Promise<BulkUpdateDraftPostsResponse & BulkUpdateDraftPostsResponseNonNullableFields>;
}
export declare function listDeletedDraftPosts(httpClient: HttpClient): ListDeletedDraftPostsSignature;
interface ListDeletedDraftPostsSignature {
    /**
     * Retrieves a list of up to 100 deleted draft posts.
     *
     * List Deleted Draft Posts runs with these defaults, which you can override:
     * - `editedDate` is sorted in descending order. In this case,`editedDate` implies the date the post was deleted.
     * - `paging.limit` is `50`.
     * - `paging.offset` is `0`.
     * @param - Options for listing deleted draft posts.
     */
    (options?: ListDeletedDraftPostsOptions | undefined): Promise<ListDeletedDraftPostsResponse & ListDeletedDraftPostsResponseNonNullableFields>;
}
export declare function getDraftPost(httpClient: HttpClient): GetDraftPostSignature;
interface GetDraftPostSignature {
    /**
     * Gets a draft post by the provided ID.
     *
     * Uses the provided `draftPostId` to retrieve a draft post.
     * @param - Draft post ID.
     * @param - Options for getting a draft post.
     */
    (draftPostId: string, options?: GetDraftPostOptions | undefined): Promise<GetDraftPostResponse & GetDraftPostResponseNonNullableFields>;
}
export declare function updateDraftPost(httpClient: HttpClient): UpdateDraftPostSignature;
interface UpdateDraftPostSignature {
    /**
     * Updates a draft post.
     * @param - Draft post ID.
     * @param - Options for updating a draft post.
     * @param - Draft Post info.
     */
    (_id: string, draftPost: UpdateDraftPost, options?: UpdateDraftPostOptions | undefined): Promise<UpdateDraftPostResponse & UpdateDraftPostResponseNonNullableFields>;
}
export declare function deleteDraftPost(httpClient: HttpClient): DeleteDraftPostSignature;
interface DeleteDraftPostSignature {
    /**
     * Moves a draft post with the provided ID to the trash bin.
     * A published post can also be deleted by its provided `draftPostId`.
     *
     * The optional `permanent` field enables you to delete a post permanently, bypassing the trash bin. When a draft post is deleted this way, it can't be restored.
     * @param - Draft post ID.
     * @param - Options for deleting a draft post.
     */
    (draftPostId: string, options?: DeleteDraftPostOptions | undefined): Promise<void>;
}
export declare function removeFromTrashBin(httpClient: HttpClient): RemoveFromTrashBinSignature;
interface RemoveFromTrashBinSignature {
    /**
     * Permanently deletes a draft post by the provided ID from the trash bin.
     *
     * Uses the provided `draftPostId` to permanently delete a draft post from the trash bin. This action is permanent and cannot be reversed.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<void>;
}
export declare function bulkDeleteDraftPosts(httpClient: HttpClient): BulkDeleteDraftPostsSignature;
interface BulkDeleteDraftPostsSignature {
    /**
     * Deletes multiple draft posts.
     * @param - Post IDs.
     * @param - Options for deleting multiple draft posts.
     */
    (postIds: string[], options?: BulkDeleteDraftPostsOptions | undefined): Promise<BulkDeleteDraftPostsResponse & BulkDeleteDraftPostsResponseNonNullableFields>;
}
export declare function listDraftPosts(httpClient: HttpClient): ListDraftPostsSignature;
interface ListDraftPostsSignature {
    /**
     * Retrieves a list of up to 100 draft posts per request.
     *
     * List Draft Posts runs with these defaults, which you can override:
     * - `editedDate` is sorted in descending order.
     * - `paging.limit` is `50`.
     * - `paging.offset` is `0`.
     * @param - Options for listing multiple draft posts.
     */
    (options?: ListDraftPostsOptions | undefined): Promise<ListDraftPostsResponse & ListDraftPostsResponseNonNullableFields>;
}
export declare function getDeletedDraftPost(httpClient: HttpClient): GetDeletedDraftPostSignature;
interface GetDeletedDraftPostSignature {
    /**
     * Gets a deleted draft post from the trash bin by the provided ID.
     *
     * Uses the provided `draftPostId` to retrieve a previously deleted draft post from the trash bin.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<GetDeletedDraftPostResponse & GetDeletedDraftPostResponseNonNullableFields>;
}
export declare function restoreFromTrashBin(httpClient: HttpClient): RestoreFromTrashBinSignature;
interface RestoreFromTrashBinSignature {
    /**
     * Restores a deleted draft post from the trash bin by the provided ID.
     *
     * Uses the `draftPostId` to restore a deleted draft post from the trash bin.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<RestoreFromTrashBinResponse & RestoreFromTrashBinResponseNonNullableFields>;
}
export declare function queryDraftPosts(httpClient: HttpClient): QueryDraftPostsSignature;
interface QueryDraftPostsSignature {
    /**
     * Retrieves a list of up to 100 draft posts, given the provided paging, filtering, and sorting.
     *
     * Query Draft Posts runs with these defaults, which you can override:
     * - `editedDate` is sorted in `DESC` order.
     * - `paging.limit` is `50`.
     * - `paging.offset` is `0`.
     * @param - Options for querying draft posts.
     */
    (options?: QueryDraftPostsOptions | undefined): DraftPostsQueryBuilder;
}
export declare function publishDraftPost(httpClient: HttpClient): PublishDraftPostSignature;
interface PublishDraftPostSignature {
    /**
     * Publishes a specified draft post by ID. This creates a new post entity with the data from the draft post.
     *
     * If the specified draft post was already published, the published post will be updated with the latest values from the draft post entity.
     * @param - Draft post ID.
     */
    (draftPostId: string): Promise<PublishDraftPostResponse & PublishDraftPostResponseNonNullableFields>;
}
export declare const onDraftCreated: EventDefinition<DraftCreatedEnvelope, "wix.blog.v3.draft_created">;
export declare const onDraftDeleted: EventDefinition<DraftDeletedEnvelope, "wix.blog.v3.draft_deleted">;
export declare const onDraftUpdated: EventDefinition<DraftUpdatedEnvelope, "wix.blog.v3.draft_updated">;
export { Action, ActionEvent, Alignment, AnchorData, AppEmbedData, AppEmbedDataAppDataOneOf, AppType, ApplicationError, ApproveDraftPostRequest, ApproveDraftPostResponse, AudioData, Background, BackgroundBackgroundOneOf, BackgroundType, BaseEventMetadata, BlockquoteData, BlogPaging, BookingData, Border, BorderColors, BulkActionMetadata, BulkCreateDraftPostsOptions, BulkCreateDraftPostsRequest, BulkCreateDraftPostsResponse, BulkCreateDraftPostsResponseNonNullableFields, BulkDeleteDraftPostsOptions, BulkDeleteDraftPostsRequest, BulkDeleteDraftPostsResponse, BulkDeleteDraftPostsResponseNonNullableFields, BulkDraftPostResult, BulkRejectDraftPostRequest, BulkRejectDraftPostResponse, BulkRevertToUnpublishedRequest, BulkRevertToUnpublishedResponse, BulkUpdateDraftPostLanguageRequest, BulkUpdateDraftPostLanguageResponse, BulkUpdateDraftPostsOptions, BulkUpdateDraftPostsRequest, BulkUpdateDraftPostsResponse, BulkUpdateDraftPostsResponseNonNullableFields, BulletedListData, ButtonData, ButtonDataType, CaptionData, Category, CategoryTranslation, CellStyle, CodeBlockData, CollapsibleListData, ColorData, Colors, CoverMedia, CoverMediaMediaOneOf, CreateDraftPostOptions, CreateDraftPostRequest, CreateDraftPostResponse, CreateDraftPostResponseNonNullableFields, Crop, CursorPaging, Cursors, Decoration, DecorationDataOneOf, DecorationType, DeleteDraftPostOptions, DeleteDraftPostRequest, DeleteDraftPostResponse, Design, Dimensions, Direction, DividerData, DocumentStyle, DomainEvent, DomainEventBodyOneOf, DraftCategoriesUpdated, DraftCreatedEnvelope, DraftDeletedEnvelope, DraftPost, DraftPostOwnerChanged, DraftPostTranslation, DraftPostsQueryBuilder, DraftPostsQueryResult, DraftTagsUpdated, DraftUpdatedEnvelope, EmbedData, EmbedMedia, EmbedThumbnail, EmbedVideo, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventData, EventMetadata, Field, FileData, FileSource, FileSourceDataOneOf, FocalPoint, FontSizeData, FontType, GIF, GIFData, GalleryData, GalleryOptions, GetDeletedDraftPostRequest, GetDeletedDraftPostResponse, GetDeletedDraftPostResponseNonNullableFields, GetDraftPostOptions, GetDraftPostRequest, GetDraftPostResponse, GetDraftPostResponseNonNullableFields, GetDraftPostTotalsRequest, GetDraftPostTotalsResponse, GetDraftPostsSort, GetPostAmountsByLanguageRequest, GetPostAmountsByLanguageResponse, Gradient, HTMLData, HTMLDataDataOneOf, HeadingData, Height, IdentificationData, IdentificationDataIdOneOf, Image, ImageData, InitialDraftPostsCopied, InitialExpandedItems, IsDraftPostAutoTranslatableRequest, IsDraftPostAutoTranslatableResponse, Item, ItemDataOneOf, ItemMetadata, ItemStyle, Keyword, Layout, LayoutCellData, LayoutType, LineStyle, Link, LinkData, LinkDataOneOf, LinkPreviewData, ListDeletedDraftPostsOptions, ListDeletedDraftPostsRequest, ListDeletedDraftPostsResponse, ListDeletedDraftPostsResponseNonNullableFields, ListDraftPostsOptions, ListDraftPostsRequest, ListDraftPostsResponse, ListDraftPostsResponseNonNullableFields, ListValue, MapData, MapSettings, MapType, MarkPostAsInModerationRequest, MarkPostAsInModerationResponse, MaskedDraftPosts, Media, MediaMediaOneOf, MentionData, MessageEnvelope, MetaData, Metadata, ModerationDetails, ModerationStatusStatus, Node, NodeDataOneOf, NodeStyle, NodeType, NullValue, Oembed, Option, OptionDesign, OptionLayout, OrderedListData, Orientation, Origin, PDFSettings, Paging, PagingMetadataV2, ParagraphData, Permissions, PlatformQuery, PlatformQueryPagingMethodOneOf, PlaybackOptions, PluginContainerData, PluginContainerDataAlignment, PluginContainerDataWidth, PluginContainerDataWidthDataOneOf, Poll, PollData, PollDataLayout, PollDesign, PollLayout, PollLayoutDirection, PollLayoutType, PollSettings, PostAmountByLanguage, PublishDraftPostRequest, PublishDraftPostResponse, PublishDraftPostResponseNonNullableFields, QueryDraftPostsOptions, QueryDraftPostsRequest, QueryDraftPostsResponse, QueryDraftPostsResponseNonNullableFields, RejectDraftPostRequest, RejectDraftPostResponse, Rel, RemoveFromTrashBinRequest, RemoveFromTrashBinResponse, RestoreFromTrashBinRequest, RestoreFromTrashBinResponse, RestoreFromTrashBinResponseNonNullableFields, RestoreInfo, RevertToUnpublishedRequest, RevertToUnpublishedResponse, RichContent, SeoSchema, Settings, SortOrder, Sorting, Source, Spoiler, SpoilerData, Status, Styles, TableCellData, TableData, Tag, Target, TextAlignment, TextData, TextNodeStyle, TextStyle, Thumbnails, ThumbnailsAlignment, TotalDraftPosts, TotalDraftPostsGroupingField, TranslateCategoryRequest, TranslateCategoryResponse, TranslateDraftRequest, TranslateDraftResponse, Type, UnpublishPostRequest, UnpublishPostResponse, UpdateDraftPost, UpdateDraftPostContentRequest, UpdateDraftPostContentRequestDraftContentOneOf, UpdateDraftPostContentResponse, UpdateDraftPostLanguageRequest, UpdateDraftPostLanguageResponse, UpdateDraftPostOptions, UpdateDraftPostRequest, UpdateDraftPostResponse, UpdateDraftPostResponseNonNullableFields, V1Media, VerticalAlignment, Video, VideoData, VideoResolution, ViewMode, ViewRole, VoteRole, WebhookIdentityType, Width, WidthType, WixMedia, } from './blog-v3-draft-draft-posts.universal.js';
